import React from 'react';
import { Meta } from '@storybook/react';
import { graphQueryResultSlice, querybuilderSlice, schemaSlice, visualizationSlice } from '../../../data-access/store';
import { configureStore } from '@reduxjs/toolkit';
import { Provider } from 'react-redux';
import {
  big2ndChamberQueryResult,
  bigMockQueryResults,
  big2ndChamberSchemaRaw,
  typesMockQueryResults,
  typesMockSchemaRaw,
} from '../../../mock-data';
import { simpleSchemaAirportRaw } from '../../../mock-data/schema/simpleAirportRaw';
import TableComponent from './tablevis';

const Mockstore = configureStore({
  reducer: {
    schema: schemaSlice.reducer,
    graphQueryResult: graphQueryResultSlice.reducer,
    visualize: visualizationSlice.reducer,
    querybuilder: querybuilderSlice.reducer,
  },
});

const Component: Meta<typeof TableComponent.component> = {
  title: 'Visualizations/TableVis',
  component: TableComponent.component,
  decorators: [
    (story) => (
      <Provider store={Mockstore}>
        <div
          style={{
            width: '100%',
            height: '100vh',
          }}
        >
          {story()}
        </div>
      </Provider>
    ),
  ],
};

export const TestWithAirport = {
  args: {
    data: bigMockQueryResults,
    schema: simpleSchemaAirportRaw,
    configuration: {
      ...TableComponent.configuration,
      displayAttributes: ['city', 'country', 'lat', 'long', 'name', 'state', 'vip'],
      displayEntity: 'airports',
    },
  },
};

export const TestWithBig2ndChamber = {
  args: {
    data: big2ndChamberQueryResult,
    schema: big2ndChamberSchemaRaw,
    configuration: {
      ...TableComponent.configuration,
      displayAttributes: ['naam', 'anc', 'img', 'leeftijd', 'height', 'partij', 'woonplaats'],
      displayEntity: 'kamerleden',
    },
  },
};
export const TestWithTypesMock = {
  args: {
    data: typesMockQueryResults,
    schema: typesMockSchemaRaw,
    configuration: {
      ...TableComponent.configuration,
      displayAttributes: ['name', 'age', 'height', 'sacked', 'birthdate', 'startingSchedule', 'commutingDuration', 'firstLogin'],
      displayEntity: 'worker',
    },
  },
};

export default Component;
